<?php

/**
 * @file
 * Drush integration for cfpurge module.
 */

/**
 * Implements hook_drush_command().
 */
function cfpurge_drush_command() {

  $commands['purge-cfcache'] = array(
    'description' => 'Drush command to clear the Cloudflare Cache.',
    'aliases' => array('pcc'),
    'options' => array(
      'hosts' => 'List of Hosts as comma separated values.',
      'tags' => 'List of tags as comma separated values.',
    ),
    'examples' => array(
      'drush pcc' => 'This is not valid usage, We need to pass either hosts or tags as option.',
      'drush pcc --hosts=www.domain1.com,www.domain2.com --tags=testtag1,testtag2' => 'Clears the cloudflare cache for the passed two domains.',
    ),
  );

  return $commands;
}

/**
 * Implements hook_drush_help().
 */
function cfpurge_drush_help($section) {
  switch ($section) {
    case 'drush:purge-cfcache':
      return dt('Granularly remove one or more files from Cloudflare\'s cache either by specifying the list of hosts as csv as first arguement or list of tags csv as second arguement.');
  }
}

/**
 * Performs the cloudflare cache files purge for given hosts and tags.
 *
 * Drush command callback for purge-cfcache.
 */
function drush_cfpurge_purge_cfcache() {

  $hosts = drush_get_option('hosts', '');
  $tags = drush_get_option('tags', '');

  if (empty($hosts) && empty($tags)) {
    drush_print(dt('Invalid Options: Please provide either --hosts or --tags'));
    return FALSE;
  }

  $res = cfpurge_purge($hosts, $tags);

  if ($res) {
    drush_print(dt('Cloudflare Cache Cleared. ID : @id', array('@id' => $res['id'])));
    return TRUE;
  }
  else {
    drush_print(dt('Failed: Cloudflare Cache Not Cleared for ' . $hosts . ' ,' . $tags));
  }
}
/**
 * Makes API call to remove one or more files from Cloudflare's cache either by specifying the list of hosts as csv as first arguement or list of tags csv as second arguement
 * @param string $hosts list of hosts as csv
 * @param type $tags list of tags as csv
 * @return boolean/array returns array of result if success, else returns FALSE
 */
function cfpurge_purge($hosts, $tags = '') {

  $api_url = variable_get('cfpurge_api_url', 'https://api.cloudflare.com/client/v4/');
  $zone_id = variable_get('cfpurge_zone_id', '');
  $api_url = $api_url . 'zones/' . $zone_id . '/purge_cache';
  
  if ( $zone_id=='' ) {
        watchdog('cfpurge', 'Error: Zone ID is missing.', array(), WATCHDOG_ERROR);
        return FALSE;
  }


  $api_headers = array('Content-Type' => 'application/json',
    'X-Auth-Email' => variable_get('cfpurge_email', ''),
    'X-Auth-Key' => variable_get('cfpurge_api_key', ''),
    "Host" => "api.cloudflare.com",
    "Connection" => "Close");

  if (!empty($tags))
    $data['tags'] = str_getcsv($tags);

  if (!empty($hosts))
    $data['hosts'] = str_getcsv($hosts);

  $api_data = json_encode($data);

// Set options.
  $options = array(
    'method' => 'POST',
    'data' => $api_data,
    'headers' => $api_headers
  );

  $return = drupal_http_request($api_url, $options);
  if (is_object($return)) {
    if (strlen(trim($return->data)) > 0) {
      $return = json_decode($return->data, TRUE);
      if ($return['success'] == 'TRUE') {
        watchdog('cfpurge', 'Success: Purge call completed ' . var_export($return, TRUE), array(), WATCHDOG_INFO);
        return $return['result'];
      }
      else {
        watchdog('cfpurge', 'Error: Purge call failed' . var_export($return, TRUE), array(), WATCHDOG_ERROR);
        watchdog('cfpurge', 'Purge URL ' . var_export($api_url, TRUE), array(), WATCHDOG_DEBUG);
        watchdog('cfpurge', 'Purge URL ' . var_export($options, TRUE), array(), WATCHDOG_DEBUG);
        return FALSE;
      }
    }
    else {
      return FALSE;
    }
  }
  else
    $return = FALSE;


  return $return;
}